# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/larayellow/yellowpage/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/larayellow/yellowpage/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Larayellow\\Yellowpage\\": "packages/larayellow/yellowpage/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Larayellow\Yellowpage\Providers\YellowpageServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Yellowpage'  => Larayellow\Yellowpage\Facades\Yellowpage::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Larayellow\\YellowpageTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Larayellow\Yellowpage\Providers\YellowpageServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Larayellow\Yellowpage\Providers\YellowpageServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Larayellow\Yellowpage\Providers\YellowpageServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/yellowpage/{modulename}

**User**

    http://path-to-route-folder/user/yellowpage/{modulename}

**Public**

    http://path-to-route-folder/yellowpages


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/yellowpage/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/yellowpage/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/yellowpage/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/yellowpage/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/yellowpage/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/yellowpage/{modulename}/{slug}
    METHOD: GET