<?php

namespace Larayellow\Yellowpage\Policies;

use Litepie\User\Contracts\UserPolicy;
use Larayellow\Yellowpage\Models\Yellowpage;

class YellowpagePolicy
{

    /**
     * Determine if the given user can view the yellowpage.
     *
     * @param UserPolicy $user
     * @param Yellowpage $yellowpage
     *
     * @return bool
     */
    public function view(UserPolicy $user, Yellowpage $yellowpage)
    {
        if ($user->canDo('yellowpage.yellowpage.view') && $user->isAdmin()) {
            return true;
        }

        return $yellowpage->user_id == user_id() && $yellowpage->user_type == user_type();
    }

    /**
     * Determine if the given user can create a yellowpage.
     *
     * @param UserPolicy $user
     * @param Yellowpage $yellowpage
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('yellowpage.yellowpage.create');
    }

    /**
     * Determine if the given user can update the given yellowpage.
     *
     * @param UserPolicy $user
     * @param Yellowpage $yellowpage
     *
     * @return bool
     */
    public function update(UserPolicy $user, Yellowpage $yellowpage)
    {
        if ($user->canDo('yellowpage.yellowpage.edit') && $user->isAdmin()) {
            return true;
        }

        return $yellowpage->user_id == user_id() && $yellowpage->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given yellowpage.
     *
     * @param UserPolicy $user
     * @param Yellowpage $yellowpage
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Yellowpage $yellowpage)
    {
        return $yellowpage->user_id == user_id() && $yellowpage->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given yellowpage.
     *
     * @param UserPolicy $user
     * @param Yellowpage $yellowpage
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Yellowpage $yellowpage)
    {
        if ($user->canDo('yellowpage.yellowpage.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given yellowpage.
     *
     * @param UserPolicy $user
     * @param Yellowpage $yellowpage
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Yellowpage $yellowpage)
    {
        if ($user->canDo('yellowpage.yellowpage.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
