<?php

namespace Larayellow\Yellowpage\Providers;

use Illuminate\Support\ServiceProvider;

class YellowpageServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'yellowpage');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'yellowpage');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerYellowpage();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerYellowpage()
    {
        $this->app->bind('yellowpage', function($app) {
            return new Yellowpage($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Yellowpage', 'Lavalite\Yellowpage\Facades\Yellowpage');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('larayellow.yellowpage', function ($app) {
            return $this->app->make('Larayellow\Yellowpage\Yellowpage');
        });

                // Bind Yellowpage to repository
        $this->app->bind(
            'Larayellow\Yellowpage\Interfaces\YellowpageRepositoryInterface',
            \Larayellow\Yellowpage\Repositories\Eloquent\YellowpageRepository::class
        );

        $this->app->register(\Larayellow\Yellowpage\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Larayellow\Yellowpage\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and yellowpage's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'larayellow.yellowpage'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeYellowpage::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['larayellow.yellowpage'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('larayellow/yellowpage.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/yellowpage')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/yellowpage')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
